@@ -17,26 +17,22 @@ class DDC3711EntityA
     /** @var ArrayCollection */
     private $entityB;
 
-    /** @return mixed */
-    public function getId1()
+    public function getId1(): mixed
     {
         return $this->id1;
     }
 
-    /** @param mixed $id1 */
-    public function setId1($id1): void
+    public function setId1(mixed $id1): void
     {
         $this->id1 = $id1;
     }
 
-    /** @return mixed */
-    public function getId2()
+    public function getId2(): mixed
     {
         return $this->id2;
     }
 
-    /** @param mixed $id2 */
-    public function setId2($id2): void
+    public function setId2(mixed $id2): void
     {
         $this->id2 = $id2;
     }
