@@ -6,17 +6,11 @@ namespace Doctrine\Tests\Models\DDC869;
 
 use Doctrine\ORM\Mapping as ORM;
 use Doctrine\ORM\Mapping\ClassMetadata;
-use Doctrine\ORM\Mapping\Column;
-use Doctrine\ORM\Mapping\Entity;
 
-/** @Entity */
 #[ORM\Entity]
 class DDC869CreditCardPayment extends DDC869Payment
 {
-    /**
-     * @var string
-     * @Column(type="string", length=255)
-     */
+    /** @var string */
     #[ORM\Column(type: 'string')]
     protected $creditCardNumber;
 
@@ -26,7 +20,7 @@ class DDC869CreditCardPayment extends DDC869Payment
             [
                 'fieldName'  => 'creditCardNumber',
                 'type'       => 'string',
-            ]
+            ],
         );
     }
 }
