@@ -9,6 +9,5 @@ namespace Doctrine\Tests\Models\Reflection;
  */
 abstract class AbstractEmbeddable
 {
-    /** @var string */
-    private $propertyInAbstractClass;
+    private string $propertyInAbstractClass;
 }
