@@ -16,11 +16,12 @@ use Doctrine\ORM\Mapping\OneToMany;
 use Doctrine\ORM\Mapping\Table;
 use Doctrine\ORM\PersistentCollection;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use PHPUnit\Framework\Attributes\Group;
 
 use function array_unique;
 use function count;
 
-/** @group GH-5762 */
+#[Group('GH-5762')]
 class GH5762Test extends OrmFunctionalTestCase
 {
     protected function setUp(): void
@@ -30,7 +31,7 @@ class GH5762Test extends OrmFunctionalTestCase
         $this->createSchemaForModels(
             GH5762Driver::class,
             GH5762DriverRide::class,
-            GH5762Car::class
+            GH5762Car::class,
         );
     }
 
@@ -57,8 +58,7 @@ class GH5762Test extends OrmFunctionalTestCase
         self::assertContains('Volvo', $cars);
     }
 
-    /** @return mixed */
-    private function fetchData()
+    private function fetchData(): mixed
     {
         $this->createData();
 
@@ -107,102 +107,61 @@ class GH5762Test extends OrmFunctionalTestCase
     }
 }
 
-/**
- * @Entity
- * @Table(name="driver")
- */
+#[Table(name: 'driver')]
+#[Entity]
 class GH5762Driver
 {
-    /**
-     * @var int
-     * @Id
-     * @Column(type="integer")
-     * @GeneratedValue(strategy="NONE")
-     */
-    public $id;
-
-    /**
-     * @var string
-     * @Column(type="string", length=255)
-     */
-    public $name;
-
-    /**
-     * @phpstan-var Collection<int, GH5762DriverRide>
-     * @OneToMany(targetEntity="GH5762DriverRide", mappedBy="driver")
-     */
+    /** @phpstan-var Collection<int, GH5762DriverRide> */
+    #[OneToMany(targetEntity: 'GH5762DriverRide', mappedBy: 'driver')]
     public $driverRides;
 
-    public function __construct(int $id, string $name)
-    {
+    public function __construct(
+        #[Id]
+        #[Column(type: 'integer')]
+        #[GeneratedValue(strategy: 'NONE')]
+        public int $id,
+        #[Column(type: 'string', length: 255)]
+        public string $name,
+    ) {
         $this->driverRides = new ArrayCollection();
-        $this->id          = $id;
-        $this->name        = $name;
     }
 }
 
-/**
- * @Entity
- * @Table(name="driver_ride")
- */
+#[Table(name: 'driver_ride')]
+#[Entity]
 class GH5762DriverRide
 {
-    /**
-     * @var GH5762Driver
-     * @Id
-     * @ManyToOne(targetEntity="GH5762Driver", inversedBy="driverRides")
-     * @JoinColumn(name="driver_id", referencedColumnName="id")
-     */
-    public $driver;
-
-    /**
-     * @var GH5762Car
-     * @Id
-     * @ManyToOne(targetEntity="GH5762Car", inversedBy="carRides")
-     * @JoinColumn(name="car", referencedColumnName="brand")
-     */
-    public $car;
-
-    public function __construct(GH5762Driver $driver, GH5762Car $car)
-    {
-        $this->driver = $driver;
-        $this->car    = $car;
-
+    public function __construct(
+        #[Id]
+        #[ManyToOne(targetEntity: 'GH5762Driver', inversedBy: 'driverRides')]
+        #[JoinColumn(name: 'driver_id', referencedColumnName: 'id')]
+        public GH5762Driver $driver,
+        #[Id]
+        #[ManyToOne(targetEntity: 'GH5762Car', inversedBy: 'carRides')]
+        #[JoinColumn(name: 'car', referencedColumnName: 'brand')]
+        public GH5762Car $car,
+    ) {
         $this->driver->driverRides->add($this);
         $this->car->carRides->add($this);
     }
 }
 
-/**
- * @Entity
- * @Table(name="car")
- */
+#[Table(name: 'car')]
+#[Entity]
 class GH5762Car
 {
-    /**
-     * @var string
-     * @Id
-     * @Column(type="string", length=25)
-     * @GeneratedValue(strategy="NONE")
-     */
-    public $brand;
-
-    /**
-     * @var string
-     * @Column(type="string", length=255)
-     */
-    public $model;
-
-    /**
-     * @phpstan-var Collection<int, GH5762DriverRide>
-     * @OneToMany(targetEntity="GH5762DriverRide", mappedBy="car")
-     */
+    /** @phpstan-var Collection<int, GH5762DriverRide> */
+    #[OneToMany(targetEntity: 'GH5762DriverRide', mappedBy: 'car')]
     public $carRides;
 
-    public function __construct($brand, $model)
-    {
+    public function __construct(
+        #[Id]
+        #[Column(type: 'string', length: 25)]
+        #[GeneratedValue(strategy: 'NONE')]
+        public string $brand,
+        #[Column(type: 'string', length: 255)]
+        public string $model,
+    ) {
         $this->carRides = new ArrayCollection();
-        $this->brand    = $brand;
-        $this->model    = $model;
     }
 }
