@@ -54,7 +54,7 @@ use DoctrineGlobalArticle;
 use LogicException;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\Group as TestGroup;
-use PHPUnit\Framework\Attributes\WithoutErrorHandler;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use ReflectionClass;
 use stdClass;
 
@@ -1126,7 +1126,7 @@ class ClassMetadataTest extends OrmTestCase
         $metadata->addLifecycleCallback('foo', 'bar');
     }
 
-    #[WithoutErrorHandler]
+    #[IgnoreDeprecations]
     public function testGettingAnFQCNForNullIsDeprecated(): void
     {
         $metadata = new ClassMetadata(self::class);
@@ -1165,7 +1165,7 @@ class ClassMetadataTest extends OrmTestCase
         );
     }
 
-    #[WithoutErrorHandler]
+    #[IgnoreDeprecations]
     public function testDiscriminatorMapWithSameClassMultipleTimesDeprecated(): void
     {
         $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/3519');
