@@ -10,6 +10,7 @@ use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\EntityNotFoundException;
 use Doctrine\ORM\Mapping\ClassMetadata;
+use Doctrine\ORM\ORMInvalidArgumentException;
 use Doctrine\ORM\Persisters\Entity\BasicEntityPersister;
 use Doctrine\ORM\Proxy\ProxyFactory;
 use Doctrine\Persistence\Mapping\RuntimeReflectionService;
@@ -22,10 +23,12 @@ use Doctrine\Tests\Models\ECommerce\ECommerceFeature;
 use Doctrine\Tests\OrmTestCase;
 use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\IgnoreDeprecations;
+use PHPUnit\Framework\Attributes\RequiresMethod;
 use PHPUnit\Framework\Attributes\RequiresPhp;
 use ReflectionClass;
 use ReflectionProperty;
 use stdClass;
+use Symfony\Component\VarExporter\ProxyHelper;
 
 use function assert;
 use function method_exists;
@@ -247,6 +250,7 @@ class ProxyFactoryTest extends OrmTestCase
     }
 
     #[RequiresPhp('8.4')]
+    #[RequiresMethod(ProxyHelper::class, 'generateLazyGhost')]
     #[IgnoreDeprecations]
     public function testProxyFactoryTriggersDeprecationWhenNativeLazyObjectsAreDisabled(): void
     {
@@ -276,6 +280,25 @@ class ProxyFactoryTest extends OrmTestCase
             ProxyFactory::AUTOGENERATE_ALWAYS,
         );
     }
+
+    public function testProxyFactoryThrowsIfLazyGhostsAreUnavailable(): void
+    {
+        if (method_exists(ProxyHelper::class, 'generateLazyGhost')) {
+            self::markTestSkipped('This test is not relevant when lazy ghosts are available');
+        }
+
+        $this->emMock->getConfiguration()->enableNativeLazyObjects(false);
+
+        $this->expectException(ORMInvalidArgumentException::class);
+        $this->expectExceptionMessage('Symfony LazyGhost is not available. Please install the "symfony/var-exporter" package version 6.4 or 7 to use this feature or enable PHP 8.4 native lazy objects.');
+
+        new ProxyFactory(
+            $this->emMock,
+            sys_get_temp_dir(),
+            'Proxies',
+            ProxyFactory::AUTOGENERATE_ALWAYS,
+        );
+    }
 }
 
 abstract class AbstractClass
